#!/bin/sh
#
# Copyright 2013 Adi Roiban
#
# Script for launching the file transfer client shell on Unix-like systems.
# Uses the default /bin/sh shell. Tested with the OS'es supported by SFTPPlus.
PATH=/bin:/usr/bin:/usr/local/bin:"$PATH"

# PATH needs to be exported, as otherwise it is not available in sub-processes.
export PATH

if ! command -v dirname >/dev/null 2>&1; then
    printf "Missing \"dirname\" command.\n"
    exit 254
fi

# POSIX shell assurances.
set -o nounset
set -o errexit

bin_relative_path="$(dirname "$0")"

# Using pwd in a sub-shell, get the absolute path to the sub-dir of this script.
bin_path=$(cd "$bin_relative_path" && pwd)

if [ -z "$bin_path" ]; then
    printf "Couldn't determine absolute path for \"%s\".\n" "$0"
    exit 253
fi

export PATH="$bin_path":"$PATH"
export LD_LIBRARY_PATH="$bin_path"/../lib

exec "$bin_path"/python -X utf8 -m chevah.server.location "$@"
