#!/bin/sh
#
# Copyright 2022 ProAtria team
#
# Script for rolling back SFTPPlus to a previous backup on Linux / Unix.
# Uses the default /bin/sh shell. Tested with the OS'es supported by SFTPPlus.
#
# It supports rolling back to the version saved in the expected backup location.

if ! command -v dirname >/dev/null 2>&1; then
    printf "Missing \"dirname\" command.\n"
    exit 254
fi

# POSIX shell assurances.
set -o nounset
set -o errexit

bin_relative_path="$(dirname "$0")"

# Using pwd in a sub-shell, get the absolute path to the sub-dir of this script.
bin_path=$(cd "$bin_relative_path" && pwd)

if [ -z "$bin_path" ]; then
    printf "Couldn't determine absolute path for \"%s\".\n" "$0"
    exit 253
fi

export INSTALL_DIR="${bin_path%/bin}"

if [ "$(uname)" = "AIX" ]; then
    # Avoid the error "@: parameter not set" when there is no parameter,
    # as the behaviour of the default /bin/sh is different on AIX.
    set +o nounset
fi

# Show this help message and exit.
# Whenever editing this, check alignment of opts / associated text and length.
command_show_help() {
    printf "\nUsage:\n"
    printf "  %s [OPTIONS] [BACKUP_DIRECTORY_PATH]\n" "$0"
    printf "\nOptions:\n"
    printf "  -h, --help\t\t\tShow this help message and exit\n"
    printf "  BACKUP_DIRECTORY_PATH\t\tPath to a custom backup directory\n"
    printf "\nWhen no custom backup directory path is provided, this script\n"
    printf "rolls back to the SFTPPlus backup in the default location:\n"
    printf "\"/opt/sftpplus_backups/sftpplus-mft_UPDATE_AUTO_BACKUP\".\n"
    printf "This assumes the default SFTPPlus instance name, \"sftpplus-mft\","
    printf "\nwas not changed.\n"
    exit 0
}

# Get command line parameters and act accordingly
while getopts "h-:" opt; do
    case $opt in
        h)
            command_show_help
            ;;
        -)
            # getopts doesn't support long opts such as --help.
            case "$OPTARG" in
                help)
                    command_show_help
                    ;;
                *)
                    printf "Invalid option: --%s\n" "$OPTARG"
                    exit 1
                    ;;
            esac
            ;;
        \?)
            # Unknown option.
            exit 1
            ;;
    esac
done

exec /bin/sh "$INSTALL_DIR"/bin/setup_helper.sh rollback "$@"
